@@ -2,8 +2,8 @@
 #
 # read.cross.karl.R
 #
-# copyright (c) 2000-2011, Karl W Broman
-# last modified May, 2011
+# copyright (c) 2000-2019, Karl W Broman
+# last modified Dec, 2019
 # first written Aug, 2000
 #
 #     This program is free software; you can redistribute it and/or
@@ -149,9 +149,8 @@ read.cross.karl <-
     class(cross) <- c(type,"cross")
 
     # check that nothing is strange in the genotype data
-    cross.type <- class(cross)[1]
-    if(cross.type=="f2") max.gen <- 5
-    else if(cross.type=="bc") max.gen <- 2
+    if(type=="f2") max.gen <- 5
+    else if(type=="bc") max.gen <- 2
     else max.gen <- 14
 
     u <- unique(geno)
