@@ -2,8 +2,8 @@
 #
 # summary.scanone.R
 #
-# copyright (c) 2001-2015, Karl W Broman
-# last modified Oct, 2015
+# copyright (c) 2001-2019, Karl W Broman
+# last modified Dec, 2019
 # first written Sep, 2001
 #
 #     This program is free software; you can redistribute it and/or
@@ -35,7 +35,7 @@ summary.scanone <-
              perms, alpha, lodcolumn=1, pvalues=FALSE,
              ci.function=c("lodint", "bayesint"), ...)
 {
-    if(!any(class(object) == "scanone"))
+    if(!inherits(object, "scanone"))
         stop("Input should have class \"scanone\".")
 
     format <- match.arg(format)
@@ -51,9 +51,9 @@ summary.scanone <-
         warning("lodcolumn ignored except when format=\"onepheno\".")
 
     if(!missing(perms)) {
-        if("scantwoperm" %in% class(perms))
+        if(inherits(perms, "scantwoperm"))
             perms <- scantwoperm2scanoneperm(perms)
-        else if(!("scanoneperm" %in% class(perms)))
+        else if(!inherits(perms, "scanoneperm"))
             warning("perms need to be in scanoneperm format.")
     }
 
@@ -158,8 +158,13 @@ summary.scanone <-
         }
         thechr <- as.character(object[wh,1])
 
-        if(!missing(threshold))
+        if(!missing(threshold)) {
+            if(length(threshold) > 1) {
+                warning('when format="allpheno", threshold should have length 1')
+                threshold <- threshold[1]
+            }
             wh <- wh[object[wh,lodcolumn] > threshold]
+        }
         else if(!missing(alpha)) {
             thr <- summary(perms, alpha)
             if("xchr" %in% names(attributes(perms))) {
@@ -556,11 +561,11 @@ print.summary.scanone <-
 max.scanone <-
     function(object, chr, lodcolumn=1, na.rm=TRUE, ...)
 {
-    if(!any(class(object) == "scanone"))
+    if(!inherits(object, "scanone"))
         stop("Input must have class \"scanone\".")
 
     if(lodcolumn < 1 || lodcolumn+2 > ncol(object))
-        stop("Argument lodcolumn misspecified.")
+        stop("Argument lodcolumn should be between 1 and ", ncol(object)-2)
 
     if(!missing(chr)) object <- subset(object, chr=chr)
 
@@ -580,7 +585,7 @@ max.scanone <-
 subset.scanone <-
     function(x, chr, lodcolumn, ...)
 {
-    if(!any(class(x) == "scanone"))
+    if(!inherits(x, "scanone"))
         stop("Input should have class \"scanone\".")
 
     if(missing(chr) && missing(lodcolumn))
@@ -629,12 +634,11 @@ c.scanone <-
     function(..., labels)
 {
     dots <- list(...)
-    cl1 <- class(dots[[1]])
-    if(length(dots)==1 && length(cl1)==1 && cl1=="list") dots <- dots[[1]]
+    if(length(dots)==1 && is.list(dots[[1]])) dots <- dots[[1]]
 
     if(length(dots)==1) return(dots[[1]])
     for(i in seq(along=dots)) {
-        if(!any(class(dots[[i]]) == "scanone"))
+        if(!inherits(dots[[i]], "scanone"))
             stop("Input should have class \"scanone\".")
     }
 
@@ -712,7 +716,7 @@ grab.arg.names <-
 summary.scanoneperm <-
     function(object, alpha=c(0.05, 0.10), controlAcrossCol=FALSE, ...)
 {
-    if(!any(class(object) == "scanoneperm"))
+    if(!inherits(object, "scanoneperm"))
         stop("Input should have class \"scanoneperm\".")
 
     if(any(alpha < 0 | alpha > 1))
@@ -829,12 +833,11 @@ rbind.scanoneperm <- c.scanoneperm <-
 {
     dots <- list(...)
 
-    cl1 <- class(dots[[1]])
-    if(length(dots)==1 && length(cl1)==1 && cl1=="list") dots <- dots[[1]]
+    if(length(dots)==1 && is.list(dots[[1]])) dots <- dots[[1]]
 
     if(length(dots)==1) return(dots[[1]])
     for(i in seq(along=dots)) {
-        if(!any(class(dots[[i]]) == "scanoneperm"))
+        if(!inherits(dots[[i]], "scanoneperm"))
             stop("Input should have class \"scanoneperm\".")
     }
 
@@ -887,7 +890,7 @@ cbind.scanoneperm <-
     if(length(dots)==1) return(dots[[1]])
 
     for(i in seq(along=dots)) {
-        if(!any(class(dots[[i]]) == "scanoneperm"))
+        if(!inherits(dots[[i]], "scanoneperm"))
             stop("Input should have class \"scanoneperm\".")
     }
 
@@ -1002,11 +1005,11 @@ subset.scanoneperm <-
             x <- lapply(x, as.matrix)
 
         if(missing(lodcolumn)) lodcolumn <- 1:ncol(x[[1]])
-        else if(!is.null(attr(try(x[[1]][,lodcolumn], silent=TRUE),"try-error")))
+        else if(!check_colindex(lodcolumn, x[[1]]))
             stop("lodcolumn misspecified.")
 
         if(missing(repl)) repl <- 1:nrow(x[[1]])
-        else if(!is.null(attr(try(x[[1]][repl,], silent=TRUE),"try-error")))
+        else if(!check_rowindex(repl, x[[1]]))
             stop("repl misspecified.")
 
         cl <- class(x)
@@ -1017,11 +1020,11 @@ subset.scanoneperm <-
         if(!is.matrix(x)) x <- as.matrix(x)
 
         if(missing(lodcolumn)) lodcolumn <- 1:ncol(x)
-        else if(!is.null(attr(try(x[,lodcolumn], silent=TRUE),"try-error")))
+        else if(!check_colindex(lodcolumn, x))
             stop("lodcolumn misspecified.")
 
         if(missing(repl)) repl <- 1:nrow(x)
-        else if(!is.null(attr(try(x[repl,], silent=TRUE),"try-error")))
+        else if(!check_rowindex(repl, x))
             stop("repl misspecified.")
 
         cl <- class(x)
@@ -1042,4 +1045,44 @@ subset.scanoneperm <-
     function(x, repl, lodcolumn)
     subset.scanoneperm(x, repl, lodcolumn)
 
+# function to check if column indices are okay
+check_colindex <-
+    function(index, mat)
+{
+    if(any(is.na(index))) return(FALSE)
+
+    n <- ncol(mat)
+
+    if(is.logical(index) && length(index) != n)
+        return(FALSE)
+    if(is.numeric(index)) {
+        if(any(index <= 0) && !all(index < 0)) return(FALSE) # don't mix pos and neg
+        if(all(index < 0) && any(index < -n)) return(FALSE) # out of bounds
+        if(all(index > 0) && any(index > n)) return(FALSE) # out of bounds
+    }
+    if(is.character(index) && !all(index %in% colnames(mat))) return(FALSE)
+
+    TRUE
+}
+
+# function to check if row indices are okay
+check_rowindex <-
+    function(index, mat)
+{
+    if(any(is.na(index))) return(FALSE)
+
+    n <- nrow(mat)
+
+    if(is.logical(index) && length(index) != n)
+        return(FALSE)
+    if(is.numeric(index)) {
+        if(any(index <= 0) && !all(index < 0)) return(FALSE) # don't mix pos and neg
+        if(all(index < 0) && any(index < -n)) return(FALSE) # out of bounds
+        if(all(index > 0) && any(index > n)) return(FALSE) # out of bounds
+    }
+    if(is.character(index) && !all(index %in% rownames(mat))) return(FALSE)
+
+    TRUE
+}
+
 # end of summary.scanone.R
